@@ -65,6 +65,17 @@ class RawDestinationConfig:
     type: DestinationType = DestinationType.raw
 
 
+@dataclass
+class RawDestinationAlternativeConfig:
+    """
+    Valid type values are: raw
+    """
+
+    database: str
+    table: str
+    type: DestinationType = DestinationType.raw
+
+
 @dataclass
 class DMIDestinationConfig:
     """
@@ -88,7 +99,12 @@ class SequenceRowsDestinationConfig:
 
 
 DestinationConfigType = Union[
-    DestinationType, DestinationConfig, RawDestinationConfig, SequenceRowsDestinationConfig, DMIDestinationConfig
+    DestinationType,
+    DestinationConfig,
+    RawDestinationConfig,
+    SequenceRowsDestinationConfig,
+    DMIDestinationConfig,
+    RawDestinationAlternativeConfig,
 ]
 
 
